import re


def parse_host_port(host_string):
    """Parse host:port into a tuple."""
    regex = re.compile(r"(\[[:a-fA-F0-9]+\]|(?:\d{1,3}\.){3}\d{1,3}|[a-zA-Z0-9.]+)(?::(\d+))?", re.X)
    m = regex.match(host_string)
    addr, port = m.group(1, 2)
    try:
        return (addr, int(port))
    except TypeError:
        # port is None
        return (addr, None)



import click

banner = click.style(
    """
 _____ _____ _____ _____
|   __|   __|  _  |   | |
|  |  |__   |     | | | |
|_____|_____|__|__|_|___|""",
    bold=True,
    fg="red",
)

version = click.style(" v4.1.2\n\n", bold=True, fg="green")
author = click.style("Author:  ", bold=True) + "Franccesco Orozco\n"
email = click.style("Email:   ", bold=True) + "franccesco@codingdose.info\n"
website = click.style("Website: ", bold=True) + "https://codingdose.info"
about_message = banner + version + author + email + website



import json

import click


def dump_filename(filename, subdomain_df):
    """Output to CSV, JSON or Clipboard."""
    filename = filename.lower()
    if filename.endswith(".json"):
        click.secho(f"\n[+] Contents dumped into JSON file: {filename}", bold=True)
        with open(filename, "w+") as file_object:
            file_object.write(json.dumps(subdomain_df.to_dict(orient="list")))
    elif filename.endswith(".csv"):
        click.secho(f"\n[+] Contents dumped into CSV file: {filename}", bold=True)
        subdomain_df.to_csv(filename, index=False)
    elif filename == "cb":
        click.secho(f"\n[+] Contents dumped into clipboard.", bold=True)
        subdomain_df.to_clipboard(index=False)
    else:
        click.secho("\n[!] Extension not recognized, dumping using CSV format.", bold=True)
        subdomain_df.to_csv(filename, index=False)



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['gsan']

package_data = \
{'': ['*']}

install_requires = \
['click>=7.0,<8.0',
 'colorama>=0.4.1,<0.5.0',
 'ndg-httpsclient>=0.5.1,<0.6.0',
 'pandas>=0.25.3,<0.26.0',
 'pyasn1>=0.4.8,<0.5.0',
 'pyopenssl>=19.1,<20.0',
 'tldextract>=2.2,<3.0']

entry_points = \
{'console_scripts': ['gsan = gsan.cli:cli']}

setup_kwargs = {
    'name': 'gsan',
    'version': '4.1.2',
    'description': 'Extract subdomains from HTTPS sites',
    'long_description': None,
    'author': 'Franccesco Orozco',
    'author_email': 'franccesco@codingdose.info',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)



import pandas as pd


def strip_chars(subdomain_df):
    """Strip *.'s and www.'s"""
    subdomain_df = subdomain_df.str.lower()
    subdomain_df = subdomain_df.str.replace("www.", "")
    subdomain_df = subdomain_df.str.replace("\*.", "")
    return subdomain_df


def filter_domain(subdomain_df, domain):
    """Filter subdomains that don't match the domain name."""
    subdomain_df = subdomain_df[subdomain_df.str.endswith(f".{domain}")]
    return subdomain_df


def reindex_df(subdomain_df):
    """Reindex subdomain dataframe and starts at indice 1."""
    subdomain_df.drop_duplicates(inplace=True)
    subdomain_df.reset_index(drop=True, inplace=True)
    subdomain_df.index += 1
    return subdomain_df


def concat_dfs(subdomain_dfs, headers):
    """Concatenate, fill N/A's and rename columns."""
    concat_df = pd.concat(subdomain_dfs, axis="columns")
    concat_df.columns = [header.upper() for header in headers]
    concat_df.dropna(axis=1, how="all", inplace=True)
    concat_df.fillna("", inplace=True)
    return concat_df
